/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is gContactSync.
 *
 * The Initial Developer of the Original Code is
 * Josh Geenen <gcontactsync@pirules.net>.
 * Portions created by the Initial Developer are Copyright (C) 2009
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
 
 function TBContact(aContact, aDirectory) {
   AbManager.checkCard(aContact, "TBContact constructor");
   if (!aDirectory instanceof AddressBook) {
     throw "Error - invalid directory sent to the TBContact constructor";
   }
   this.mAddressBook = aDirectory;
   this.mContact = aContact;
 }
 
TBContact.prototype = {
  getValue: function TBContact_getValue(aAttribute) {
    if (!aAttribute)
      throw "Error - invalid attribute sent to TBContact_getValue";
    if (aAttribute == "LastModifiedDate" && Preferences.mSyncPrefs.readOnly.value) {
      LOGGER.VERBOSE_LOG(" * Read only mode, setting LMD to 0");
      return 0;
    }
    return AbManager.getCardValue(this.mContact, aAttribute);
  },
  setValue: function TBContact_setValue(aAttribute, aValue, aUpdate) {
    AbManager.setCardValue(this.mContact, aAttribute, aValue);
    if (aUpdate) {
      return this.update();
    }
    return false;
  },
  update: function TBContact_update() {
    return this.mAddressBook.updateCard(this.mContact);
  },
  remove: function TBContact_remove() {
    this.mAddressBook.deleteCards([this.mContact]);
  },
  getName: function TBContact_getName() {
    var displayName = this.getValue("DisplayName");
    if (displayName) return displayName;
    var primaryEmail = this.getValue("PrimaryEmail");
    if (primaryEmail) return primaryEmail;
    return this.getValue("GoogleID");
  }
 };
